
;;;;------------------------------------------------------------------------------
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
FUNCTION READ_AIRS_INPUTS, airsl1b, airsl2        ;;; ,AIRS_PRES  ;, RETR_LEVELS

;+
; Creates a HDF file from the output University of Wisconsin-Madison output
; direct broadcast binary file.  Tried to be consistent with the official
; Level 2 DAAC product SDS names.  
;
;  Update for removal of Surface Pressure field
;    (Number of parameters reduced from 327 to 326)
;     Kathleen Strabala   September 2006
;  Update for removal of Surface Reflectivity fields (10)
;    (Number of parameters reduced from 326 to 316)
;     Kathleen Strabala   October 2006
;  Added emissivities for all AIRS channels, cloud top pressure and 
;    quality flag.
;    (Number of parameters increased from 316 to 2686)
;     Kathleen Strabala   November 2008
;
;
; AIRSL1B     Name of AIRS L1B file (To extract geolocation fields) 
; AIRSL2      Name of input UW-Madison AIRS L2B binary file (IMAPP format)
; OUTFILE     Name of output UW-Madison AIRS Level 2 output HDF file
;-

;- Check arguments
if (n_elements(airsl1b) eq 0)   then message, 'Argument AIRSL1B is undefined'
if (n_elements(airsl2) eq 0)    then message, 'Argument AIRSL2 is undefined' 
;if (n_elements(outfile) eq 0)  then message, 'Argument OUTFILE is undefined' 
;-------------------------------------------------------------------------------
; READ INPUT
;-------------------------------------------------------------------------------

;- Read the lat/lon data from the L1B file

hdfid = hdf_sd_start(airsl1b)
hdf_sd_varread, hdfid, 'Latitude', lat
hdf_sd_varread, hdfid, 'Longitude', lon
hdf_sd_varread, hdfid, 'topog', topo
hdf_sd_varread, hdfid, 'landFrac', landfrac
;hdf_sd_varread, hdfid, 'satroll', specfreq



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;    Added by kaba, Date: 03-05-09  ;;;;;;;;
;;;;; GOAL: Retrieve data and Time stamp from Level1b hdf file ;;;;;

 gindex=hdf_sd_attrfind(hdfid, 'coremetadata')     				 	;; Find "coremetadata", a global attribute:  
 HDF_SD_ATTRINFO,hdfid,gindex, NAME=name, TYPE=type, COUNT=count, DATA=data   ;; Read attribute info:
 pre_st0= STRPOS(data, 'RANGEENDINGDATE')        					;;; find the position of "productdatetime"
 pre_date=STRMID(data, pre_st0 -1, 110) 
 pre_st1=STRPOS(pre_date, '"')
 date0=STRMID(pre_date ,pre_st1+1, 10) 
  
 pre_st0= STRPOS(data, 'RANGEENDINGTIME')        	;;; find the position of "RANGEENDINGTIME"
 pre_date=STRMID(data, pre_st0 -1, 110) 
 pre_st1=STRPOS(pre_date, '"')
 hhmmss=STRMID(pre_date ,pre_st1+1, 8) 
  
; pre_st0= STRPOS(data, 'PRODUCTIONDATETIME')        ;;; find the position of "productdatetime"
; pre_date=STRMID(data, pre_st0 -1, 110) 
; pre_st1=STRPOS(pre_date, '"')
; date0=STRMID(pre_date ,pre_st1+1, 20) 
 
 yy=STRMID(date0, 0,4) & mm=STRMID(date0, 5,2) & dd=STRMID(date0, 8,2)
 hrs=STRMID(hhmmss, 0,2) & mins=STRMID(hhmmss, 3,2) & secs=STRMID(hhmmss, 6,2)
 
 adate={yy:yy, mm:mm, dd:dd, hrs:hrs, mins:mins, secs:secs}


 ftime=STRING(yy+'-'+ mm+'-'+dd+' '+hrs+':'+mins+':'+secs)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

hdf_sd_end, hdfid


;- Get the number of pixels and lines
dims = size(lat, /dimensions)
nx = dims[0]
ny = dims[1] 
;- print, nx, ny

;- Read the entire file (tot_bands parameters)   ;;;&&&&&&&&&&&&&&&&&&&&&& 2691
 tot_bands=2691
openr, lun, airsl2, /get_lun
uwret = fltarr(nx,tot_bands,ny)
readu,lun,uwret
free_lun, lun

;- Get the surface skin temperature
temp = fltarr(nx,1,ny)
temp = uwret(*,0,*)
sfct=reform(temp,nx,ny)

;- 101 Retrieved Temperatures
temp = fltarr(nx,101,ny)
for i = 0, 100, 1 do begin
   temp(*,i,*) = uwret(*,i+1,*)
endfor
;- Rearrange array to be consistent with JPL product
tprof = transpose(temp,[1,0,2])

;- Get the Total Precipitable Water Vapor
temp = fltarr(nx,1,ny)
temp = uwret(*,102,*)
tpw=reform(temp,nx,ny)

;- 101 Level Retrieved Humidity Profile
temp = fltarr(nx,101,ny)
for i = 0, 100, 1 do begin
   temp(*,i,*) = uwret(*,i+103,*)
endfor
;- Rearrange array to be consistent with JPL product
wprof = transpose(temp,[1,0,2])

;- Get the Total Ozone
temp = fltarr(nx,1,ny)
temp = uwret(*,204,*)
toto=reform(temp,nx,ny)

;- 101 Level Retrieved Ozone Profile
temp = fltarr(nx,101,ny)
for i = 0, 100, 1 do begin
   temp(*,i,*) = uwret(*,i+205,*)
endfor
;- Rearrange array to be consistent with JPL product
ozone = transpose(temp,[1,0,2])

;- Retrieved Emissivity at full spectrum
temp = fltarr(nx,2378,ny)
for i = 0, 2377, 1 do begin
   temp(*,i,*) = uwret(*,i+306,*)
endfor
;- Rearrange array to be consistent with JPL product
emiss = transpose(temp,[1,0,2])

;- Get the Cloud Top Pressure
temp = fltarr(nx,1,ny)
temp = uwret(*,2684,*)
ctp=reform(temp,nx,ny)

;- Get the Quality Flag
temp = fltarr(nx,1,ny)
temp = uwret(*,2685,*)
qf=reform(temp,nx,ny)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;; Added by Kaba bah, Date:03-04-2009
;;;; Goal: Add the new AIRS derieved products and output netCDF files -
;;;;;;;;;; for display in AWIPSI and McIDAS-V.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	;- Get the Lifted Index
	temp = fltarr(nx,1,ny)
	temp = uwret(*,2686,*)
	LI=reform(temp,nx,ny)

	;- Get the Convective Available Potential Energy (CAPE)
	temp = fltarr(nx,1,ny)
	temp = uwret(*,2687,*)
	CAPE=reform(temp,nx,ny)

	;- Get the Precipitable Water 1 (surface - 900 mbar),
	temp = fltarr(nx,1,ny)
	temp = uwret(*,2688,*)
	PW1=reform(temp,nx,ny)

	;- Get the Precipitable Water 2 (900 - 700 mbar)
	temp = fltarr(nx,1,ny)
	temp = uwret(*,2689,*)
	PW2=reform(temp,nx,ny)

	;- Get the Precipitable Water 3 (700 - 300 mbar)
	temp = fltarr(nx,1,ny)
	temp = uwret(*,2690,*)
	PW3=reform(temp,nx,ny)


 ;- Write out the Pressure Level information 
plevs = [0.0050,0.0161,0.0384,0.0769,0.1370,0.2244,  $
  0.3454,0.5064,0.7140,0.9753,1.2972,1.6872,2.1526,  $
  2.7009,3.3398,4.0770,4.9204,5.8776,6.9567,8.1655,  $
  9.5119,11.0038,12.6492,14.4559,16.4318,18.5847,    $
  20.9224,23.4526,26.1829,29.1210,32.2744,35.6505,   $
  39.2566,43.1001,47.1882,51.5278,56.1260,60.9895,   $
  66.1253,71.5398,77.2396,83.2310,89.5204,96.1138,   $
  103.0172,110.2366,117.7775,125.6456,133.8462,      $
  142.3848,151.2664,160.4959,170.0784,180.0183,      $
  190.3203,200.9887,212.0277,223.4415,235.2338,      $
  247.4085,259.9691,272.9191,286.2617,300.0000,      $
  314.1369,328.6753,343.6176,358.9665,374.7241,      $
  390.8926,407.4738,424.4698,441.8819,459.7118,      $
  477.9607,496.6298,515.7200,535.2322,555.1669,      $
  575.5248,596.3062,617.5112,639.1398,661.1920,      $
  683.6673,706.5654,729.8857,753.6275,777.7897,      $
  802.3714,827.3713,852.7880,878.6201,904.8659,      $
  931.5236,958.5911,986.0666,1013.9476,1042.2319,    $
  1070.9170,1100.0000]

;- Read the retrievels levels from retrieval_levels file.

rlevs = '1:0.0050, 2:0.0161, 3:0.0384, 4:0.0769, 5:0.1370, 6:0.2244, 7:0.3454, 8:0.5064, 9:0.7140, 10:0.9753, 11:1.2972, 12:1.6872, 13:2.1526, 14:2.7009, 15:3.3398, 16:4.0770, 17:4.9204, 18:5.8776, 19:6.9567, 20:8.1655, 21:9.5119, 22:11.0038, 23:12.6492, 24:14.4559, 25:16.4318, 26:18.5847, 27:20.9224, 28:23.4526, 29:26.1829, 30:29.1210, 31:32.2744, 32:35.6505, 33:39.2566, 34:43.1001, 35:47.1882, 36:51.5278, 37:56.1260, 38:60.9895, 39:66.1253, 40:71.5398, 41:77.2396, 42:83.2310, 43:89.5204, 44:96.1138, 45:103.0172, 46:110.2366, 47:117.7775, 48:125.6456, 49:133.8462, 50:142.3848, 51:151.2664, 52:160.4959, 53:170.0784, 54:180.0183, 55:190.3203, 56:200.9887, 57:212.0277, 58:223.4415, 59:235.2338, 60:247.4085, 61:259.9691, 62:272.9191, 63:286.2617, 64:300.0000, 65:314.1369, 66:328.6753, 67:343.6176, 68:358.9665, 69:374.7241, 70:390.8926, 71:407.4738, 72:424.4698, 73:441.8819, 74:459.7118, 75:477.9607, 76:496.6298, 77:515.7200, 78:535.2322, 79:555.1669, 80:575.5248, 81:596.3062, 82:617.5112, 83:639.1398, 84:661.1920, 85:683.6673, 86:706.5654, 87:729.8857, 88:753.6275, 89:777.7897, 90:802.3714, 91:827.3713, 92:852.7880, 93:878.6201, 94:904.8659, 95:931.5236, 96:958.5911, 97:986.0666, 98:1013.9476, 99:1042.2319, 100:1070.9170, 101:1100.0000'


inputs={lat:lat, lon:lon, topo:topo, landfrac:landfrac, sfct:sfct, tprof:tprof,  wprof:wprof, toto:toto, ozone:ozone, adate:adate, ftime:ftime, $
		     emiss:emiss, ctp:ctp, qf:qf, li:LI, cape:CAPE, pw1:PW1, pw2:PW2, pw3:PW3,  tpw:tpw, plevs:plevs, rlevs:rlevs }

	RETURN, inputs
END

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;--------------------------------------------------------------------------

