;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;; Sub routines that may get called and utilized in CREATE_UWL2_AIRS.             
@/media/MyBook/code/projects/airs/kathy/k03/READ_AIRS_INPUTS.pro       	 ;;reads in AIRS L1B, and L2B files, output a structure
@/media/MyBook/code/projects/airs/kathy/k03/ROTATE_AWIPS.pro
@/media/MyBook/code/projects/airs/kathy/k03/WRITE_AWIPS_NetCDF.pro		   ;;Writes netCDF output files for display in AWIPS D2D
@/media/MyBook/code/projects/airs/kathy/k03/WRITE_McIDASV_NetCDF.pro     ;;Writes netCDF output files for display in McIDAS-V
@/media/MyBook/code/projects/airs/kathy/k03/WRITE_HDF_OUT.pro		         ;;Writes HDF output files just like before but adds in new products
@/media/MyBook/code/projects/airs/kathy/k03/ROTATE_AWIPS.pro			       ;;changes the oder of a 2D data array to mach the awips D2D
@/media/MyBook/code/projects/airs/kathy/k03/RESIZE_DATA.pro		           ;;resize a dataset (data,lat,lon) pixels to a desired spatial resolution. 
@/media/MyBook/code/projects/airs/kathy/k03/REMAP_DATA.pro			         ;;Calls imagemap and maps the data into a desired map projection.
@/media/MyBook/code/projects/airs/kathy/k03/imscale.pro		               ;;scales data into bytes
@/media/MyBook/code/projects/airs/kathy/k03/imagemap.pro	               ;;Does a mapping projection and returns output
@/media/MyBook/code/projects/airs/kathy/k03/GET_FILES.pro 
@/media/MyBook/code/projects/airs/kathy/k03/hdf_sd_varread.pro		       ;;
@/media/MyBook/code/projects/airs/kathy/k03/hdf_sd_vardir.pro 		       ;;
@/media/MyBook/code/projects/airs/kathy/k03/fsc_color.pro                ;;
@/media/MyBook/code/projects/airs/kathy/k03/READ_MULTIPLE_FILES.PRO            ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

PRO CREATE_UWL2_AIRS_AWIPS, txt_file, OUTFILE, OUT_TYPE

;;;OUT_TYPE, 1=AWIPS-netCDF, 2=McIDAS-V netCDF, 3=HDF
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;-------------------------------------------------
;;;;;;;;;;;;           VARIABLES  

txt_file= '/media/MyBook/code/projects/airs/kathy/input/AIRS_AWIPS_a1.09310.0712_LIST.txt'  ;test2.txt'
OUT_TYPE=1
OUTFILE='/media/MyBook/code/projects/airs/kathy/output/'
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

   in=READ_TXT_FILE(txt_file)

	  limit= [17.00, -131.00, 52.00, -64.00]        ;;The lat and lon limts to display image in  AWIPS 
	  res=[7.0, 7.0]                                ;;The desired x and y spatial resolution to adjust data. 

       KK=SIZE(OUT_TYPE)
       IF (KK[1] EQ 7 ) THEN BEGIN   ;;;Check that out type is not a string.
            PRINT, 'OUT_TYPE MUST BE AN INTEGER: 1, 2, OR 3 NOT A STRING'
            PRINT, '1=> AWIPS netCDF, 2=>McIDAS-V netCDF, 3=>HDF'
        ENDIF ELSE BEGIN
              IF (OUT_TYPE LT 4) THEN BEGIN                    
                 input_data=READ_MULTIPLE_FILES(in)
              
                 IF (OUT_TYPE EQ 3) THEN WRITE_HDF_OUT,input_data, OUTFILE             ;;; print, HDF output 
                 IF (OUT_TYPE EQ 2) THEN WRITE_McIDASV_NetCDF,input_data, OUTFILE      ;;; print, McIDAS-V netCDF 
                 IF (OUT_TYPE EQ 1) THEN BEGIN
                    rin= RESIZE_DATA(input_data, res, limit)  ;;Adjust pixels to desired resolution
                    rrin=REMAP_DATA(rin,limit)                ;;Remap to fit AWIPS projection
                    WRITE_AWIPS_NetCDF,rrin, limit, OUTFILE   ;; write output for AWIPS display
               ENDIF
                
             ENDIF ELSE BEGIN
                 PRINT, 'OUT_TYPE MUST BE AN INTEGER: ONLY 1, 2, OR 3 ALLOWED'
                PRINT, '1=> AWIPS netCDF, 2=>McIDAS-V netCDF, 3=>HDF'
             ENDELSE 
         ENDELSE
    PRINT, 'Done making netCDF files'
 END
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;




;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;Functions ;;;;;;;;;;;;;;;;;;;;;;;;;;
FUNCTION READ_TXT_FILE, infile

        f_path=STRARR(6) &  astring=''

        OPENR, lun,infile, /GET_LUN
              index = 0
              WHILE (not EOF(lun)) DO BEGIN
                    READF, lun, astring    ;f_path(index)
                    f_path(index)=astring
                    index = index + 1
              ENDWHILE
       FREE_LUN, lun
   
in_files={file:f_path, tot_files:index}

RETURN, in_files
END
